@@ -50,8 +50,8 @@ GittinsBrezziLaiPolicy          <- R6::R6Class(
       p_hat <- self$theta$mean[[arm]]
       v_arm <- p_hat*(1 - p_hat)
       v_mean <- p_hat*(1 - p_hat)/(self$theta$n[[arm]] + 1)
-      c <- - log(self$discount)
-      self$theta$gittins_index[[arm]] <- p_hat + sqrt(v_mean) * private$phi(v_mean/(c * v_arm))
+      cc <- - log(self$discount)
+      self$theta$gittins_index[[arm]] <- p_hat + sqrt(v_mean) * private$phi(v_mean/(cc * v_arm))
     },
     phi = function(s) {
       if (s > 15) {
